/*
 * Copyright 2004-2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.compass.core.config.builder;

import java.io.IOException;
import java.io.InputStream;
import java.util.Map;
import java.util.Properties;

import org.compass.core.config.CompassConfiguration;
import org.compass.core.config.ConfigurationException;
import org.compass.core.util.SystemPropertyUtils;

/**
 * A proeprties based configuration builder.
 *
 * @author kimchy
 */
public class PropertiesConfigurationBuilder extends AbstractInputStreamConfigurationBuilder {

    protected void doConfigure(InputStream is, String resourceName, CompassConfiguration config) throws ConfigurationException {
        Properties props = new Properties();
        try {
            props.load(is);
        } catch (IOException e) {
            throw new ConfigurationException("Failed to read properties configuration from [" + resourceName + "]", e);
        }
        for (Map.Entry entry : props.entrySet()) {
            config.getSettings().setSetting((String) entry.getKey(), SystemPropertyUtils.resolvePlaceholders((String) entry.getValue()));
        }
    }
}
