/*
 * Copyright 2004-2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.compass.core.converter.basic;

import java.net.URI;
import java.net.URISyntaxException;

import org.compass.core.Property;
import org.compass.core.converter.ConversionException;
import org.compass.core.mapping.ResourcePropertyMapping;
import org.compass.core.marshall.MarshallingContext;

/**
 * @author kimchy
 */
public class URIConverter extends AbstractBasicConverter<URI> {

    protected URI doFromString(String str, ResourcePropertyMapping resourcePropertyMapping, MarshallingContext context) throws ConversionException {
        try {
            return new URI(str);
        } catch (URISyntaxException e) {
            throw new ConversionException("Failed to convert uri", e);
        }
    }

    /**
     * URI is {@link org.compass.core.Property.Index#NOT_ANALYZED} by default.
     */
    public Property.Index suggestIndex() {
        return Property.Index.NOT_ANALYZED;
    }
}